From 46d5bb58c2cfceffa34932eb3105ed9c45bcb56e Mon Sep 17 00:00:00 2001
From: Matthew Woehlke <matthew.woehlke@kitware.com>
Date: Thu, 7 Nov 2013 17:46:34 -0500
Subject: [PATCH] Bug 711639 - #include does not work with absolute paths

Fix findFile() in pre.l (used to find #include files) to correctly
handle #include of an absolute file path.
---
 src/pre.l | 15 +++++++++++++++
 1 file changed, 15 insertions(+)

diff --git a/src/pre.l b/src/pre.l
index 822eb65..a4abafc 100644
--- a/src/pre.l
+++ b/src/pre.l
@@ -510,6 +510,21 @@ static FileState *checkAndOpenFile(const QCString &fileName,bool &alreadyInclude
 static FileState *findFile(const char *fileName,bool localInclude,bool &alreadyIncluded)
 {
   //printf("** findFile(%s,%d) g_yyFileName=%s\n",fileName,localInclude,g_yyFileName.data());
+  if (portable_isAbsolutePath(fileName))
+  {
+    QCString absName = fileName;
+    FileState *fs = checkAndOpenFile(absName,alreadyIncluded);
+    if (fs)
+    {
+      setFileName(absName);
+      g_yyLineNr=1;
+      return fs;
+    }
+    else if (alreadyIncluded)
+    {
+      return 0;
+    }
+  }
   if (localInclude && !g_yyFileName.isEmpty())
   {
     QFileInfo fi(g_yyFileName);
-- 
1.8.1.4

